.. _examples-models:

Models
======

The :mod:`pulse2percept.models` module provides a number of published and
verified computational models that can be used to predict neural responses or
visual percepts resulting from electrical stimulation, such as
:py:class:`~pulse2percept.models.Nanduri2012Model` and
:py:class:`~pulse2percept.models.AxonMapModel`.

New models can be created by mixing-and-matching spatial and temporal models,
or by creating a new one from scratch.